timeseries.test_mollifier — GDA Toolbox v1.0 Manual

# timeseries.test_mollifier

Test the mollifier code

## Copyright

- This file is part of https://github.com/geomdata/gda-public/
- 2015, 2016, 2017 by Geometric Data Analytics, Inc. (http://geomdata.com)
- AGPL license. See LICENSE or https://github.com/geomdata/gda-public/blob/master/LICENSE

Classes

`TestMollifier` |

### Table of Contents

- timeseries.test_mollifier
  - Copyright

#### Previous topic

timeseries.jagged

#### Next topic

timeseries.test_mollifier.TestMollifier